@@ -23,7 +23,9 @@ SUBCMD_LOG = "log"
 SUBCMD_REPORT = "report"
 
 COL_COMMIT_DATETIME = "commit_dt"
+COL_COMMIT_DATETIME_UTC = "commit_dt_utc"
 COL_LOG_DATETIME = "log_dt"
+COL_LOG_DATETIME_UTC = "log_dt_utc"
 COL_CATEGORY = "category"
 COL_TYPE = "type"
 COL_TASK_IDENTIFIER = "identifier"
